@@ -1,14 +1,14 @@
 package Evo::Guard;
-use Evo::Base -strict;
+use Evo -class;
+has '_cb';
 
 sub new {
-  my $class = shift;
   Carp::croak "You have to save Evo::Guard object to the variable"
     unless defined wantarray;
-  bless {cb => $_[0]}, $class;
+  $_[0]->SUPER::new(_cb => $_[1]);
 }
 
-sub DESTROY { (delete $_[0]->{cb})->($@ ? $@ : ()) if $_[0]->{cb} }
+sub DESTROY { (delete $_[0]->{_cb})->($@ ? $@ : ()) if $_[0]->{_cb} }
 
 1;
 
@@ -26,7 +26,7 @@ Evo::Guard - A guard
 
 =head1 VERSION
 
-version 0.0161
+version 0.0170
 
 =head1 SYNOPSIS
 
@@ -48,7 +48,7 @@ version 0.0161
 
 Executes a code when no refs are pointed to this object.
 The behavoiur is similar to L<Guard/"guard">, but this module is pure
-perl (and about 70-80% slower) and covers more cases.
+perl and covers more cases.
 
 It can be used to do some cleanups no matter was exception thrown or not.
 Or it can do something usefull only on exceptions
