@@ -1,5 +1,17 @@
 package Evo::Util;
-use Evo::Base -strict;
+use Evo;
+
+# copypast from mojo util
+sub camelize {
+  my $str = shift;
+  return $str if $str =~ /^[A-Z]/;
+
+  # CamelCase words
+  return join '::', map {
+    join('', map { ucfirst lc } split '_')
+  } split '-', $str;
+}
+
 
 # die outside dsl_call (if dsl_stash not exists)
 # die if trying to get unexisting value by key
@@ -24,14 +36,6 @@ sub _dsl_stash {
   $self;
 }
 
-sub run_wrappers {
-  my ($mngr, $cb) = (shift, pop);
-  my @wrappers = reverse @_;
-  foreach my $w (@wrappers) {
-    $cb = $w->($mngr, $cb);
-  }
-  return $cb;
-}
 
 1;
 
@@ -47,7 +51,7 @@ Evo::Util
 
 =head1 VERSION
 
-version 0.0161
+version 0.0170
 
 =head1 DESCRIPTION
 
