@@ -1,26 +1,28 @@
 package Railway::Cleanup;
-use Evo::Base -base;
+use Evo -class;
 
-sub cleanup($self) { delete $self->{$_} for $self->cleanup_list }
+sub cleanup { delete $_[0]->{$_} for $_[0]->cleanup_list }
 
 state $CLEANUP_ATTRS = {};
 
-sub register_cleanup($class, $attr) {
+sub register_cleanup {
+  my ($class, $attr) = @_;
   $class = ref $class || $class;
   $CLEANUP_ATTRS->{$class} //= [];
-  push $CLEANUP_ATTRS->{$class}->@*, ref $attr eq 'ARRAY' ? (@$attr) : $attr;
+  push @{$CLEANUP_ATTRS->{$class}}, ref $attr eq 'ARRAY' ? (@$attr) : $attr;
 }
 
 sub attr_cleanup {
   my ($class, $attr, $default) = @_;
   $class->register_cleanup($attr);
-  $class->attr($attr, $default);
+  Evo::Class::attr($class, $attr, $default);
 }
 
-sub cleanup_list($class) {
+sub cleanup_list {
+  my $class = shift;
   my @list;
-  my @classes = (ref($class) || $class, _parents($_[0]));
-  $CLEANUP_ATTRS->{$_} && push @list, $CLEANUP_ATTRS->{$_}->@* for @classes;
+  my @classes = (ref($class) || $class, _parents($class));
+  $CLEANUP_ATTRS->{$_} && push @list, @{$CLEANUP_ATTRS->{$_}} for @classes;
   @list;
 }
 
@@ -56,7 +58,7 @@ Railway::Cleanup - autocleaner
 
 =head1 VERSION
 
-version 0.0161
+version 0.0170
 
 =head1 METHODS
 
