@@ -1,12 +1,10 @@
 package Railway::Train;
-use Evo::Base 'Railway::Cleanup';
-use Evo::Util;
+use Evo 'Railway::Cleanup';
 use Evo::Guard;
-
-has 'manager';
+use Module::Load ();
 
 __PACKAGE__->attr_cleanup([qw(done cargo index)]);
-__PACKAGE__->attr_cleanup('way' => sub { $_[0]->manager->build_way });
+__PACKAGE__->attr_cleanup('way' => sub { Evo::dep_new 'Railway::Way'; });
 __PACKAGE__->register_cleanup('power');
 
 sub power {
@@ -22,7 +20,8 @@ sub power {
 }
 
 # main loop
-sub run($self) {
+sub run {
+  my $self = shift;
   Carp::croak 'no power, dispatch or start first' unless $self->power;
 
   while ($self->can_run) {
@@ -31,14 +30,15 @@ sub run($self) {
     $self->depart;
   }
 
-  my $guard = Evo::Guard->new(sub { $self->cleanup });
+  my $guard = Evo::dep_new Evo::Guard, sub { $self->cleanup };
 
   $self->done && $self->done->($self);
   return;
 }
 
 # prepare train or die
-sub prepare($self) {
+sub prepare {
+  my $self = shift;
   Carp::croak "already started" if defined $self->{index};
   $self->{index} = 0;
   Carp::croak "no stations" unless $self->can_run;
@@ -46,31 +46,35 @@ sub prepare($self) {
 }
 
 # prepare and run
-sub start($self, $done=undef) {
+sub start {
+  my ($self, $done) = @_;
   $self->prepare;
   $done && $self->done($done);
   $self->run;
 }
 
-sub can_run($self) {
+sub can_run {
+  my $self = shift;
   my $way = $self->way or return;
-  $self->{index} < $way->stations->@*;
+  $self->{index} < @{$way->stations};
 }
 
 # invoke or cleanup
-sub handle_station($self, $station) {
-  my $guard = Evo::Guard->new(sub { $_[0] and $self->cleanup });
+sub handle_station {
+  my ($self, $station) = @_;
+  my $guard = Evo::dep_new 'Evo::Guard', sub { $_[0] and $self->cleanup };
   $station->($self);
 }
 
 # leave dsl_stash station
-sub depart($self) {
+sub depart {
+  my $self = shift;
   Carp::croak 'start train first' unless defined $self->{index};
   $self->{index}++;
   $self;
 }
 
-sub get_station($self) { $self->way->get($self->{index}); }
+sub get_station { $_[0]->way->get($_[0]->{index}); }
 
 1;
 
@@ -88,7 +92,7 @@ Railway::Train - a running engine
 
 =head1 VERSION
 
-version 0.0161
+version 0.0170
 
 =head1 SYNOPSIS
 
