@@ -1,10 +1,18 @@
 package Railway::Way;
-use Evo::Base -base;
+use Evo -class;
 
 has stations => sub { [] };
 
-sub add($self, $code) { push $self->stations->@*, $code; $self }
-sub get($self, $index) { $self->stations->[$index] }
+sub add {
+  my ($self, $code) = @_;
+  push @{$self->stations}, $code;
+  $self;
+}
+
+sub get {
+  my ($self, $index) = @_;
+  $self->stations->[$index];
+}
 
 1;
 
@@ -22,7 +30,7 @@ Railway::Way - A way, a queue of stations
 
 =head1 VERSION
 
-version 0.0161
+version 0.0170
 
 =head1 SYNOPSIS
 
